@@ -26,7 +26,11 @@
 #include <tqstring.h>
 #include <list>
 
-#include <tdehardwaredevices.h>
+#ifdef __TDE_HAVE_TDEHWLIB
+class TDEHardwareDevices;
+#else
+#define TDEHardwareDevices void
+#endif
 
 /**
  * BatterySrc fetches the state of charge of the battery from HAL
